magneticalc.ExportContainer_Dialog.ExportContainer_Dialog

# ``magneticalc`.`ExportContainer_Dialog`.`ExportContainer_Dialog``

class documentation

`class ExportContainer_Dialog(QDialog2):`

Constructor: `ExportContainer_Dialog(gui)`

View In Hierarchy

ExportContainer_Dialog class.

Method | `__init__` | Initializes the dialog.
Method | `export` | Exports wire points, current and fields to some HDF5 container file.
Instance Variable | `checkboxes` | Undocumented
Instance Variable | `Export_Names_Available_Map` | Undocumented
Instance Variable | `gui` | Undocumented

Inherited from `QDialog2`:

Method | `show` | Shows this dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted` (via `QDialog2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`

Initializes the dialog.

Parameters
gui: `GUI` | GUI

def export(self):

Exports wire points, current and fields to some HDF5 container file.

checkboxes: `dict` =

Undocumented

Export_Names_Available_Map =

Undocumented

gui =

Undocumented